==> pam_flutter-1.1.33.tar.gz: lib/pam_notification.dart <==
import 'dart:convert';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_local_notifications/flutter_local_notifications.dart';
import 'package:pam_flutter/models/pam_message_model.dart';
import 'package:pam_flutter/pam_flutter.dart';
import 'package:pam_flutter/types.dart';
import 'package:flutter/services.dart' show rootBundle;

class PamNotification {
  PamNotification._();

  static String? _appPrefix;

  static Future<String> appPrefix() async {
    if (_appPrefix == null) {
      String raw = await rootBundle.loadString("pam-config.json");
      Map<String, dynamic> cfg = json.decode(raw);
      _appPrefix = cfg["app-prefix"];
    }
    return _appPrefix!;
  }

  static Future<void> pamInitial() async {
    FlutterLocalNotificationsPlugin flutterLocalNotificationsPlugin =
        FlutterLocalNotificationsPlugin();
    AndroidInitializationSettings initializationSettingsAndroid =
        AndroidInitializationSettings('app_icon');

    final IOSInitializationSettings initializationSettingsIOS =
        IOSInitializationSettings(
            onDidReceiveLocalNotification: _onDidReceiveLocalNotification);
    final InitializationSettings initializationSettings =
        InitializationSettings(
            android: initializationSettingsAndroid,
            iOS: initializationSettingsIOS);

    await flutterLocalNotificationsPlugin.initialize(initializationSettings,
        onSelectNotification: _selectNotification);
  }

  static Future _onDidReceiveLocalNotification(
      int id, String? title, String? body, String? payload) async {
    print("onDidReceiveLocalNotification");
    // showDialog(
    //   context: context,
    //   builder: (BuildContext context) => CupertinoAlertDialog(
    //     title: Text(title),
    //     content: Text(body),
    //     actions: [
    //       CupertinoDialogAction(
    //         isDefaultAction: true,
    //         child: Text('Ok'),
    //         onPressed: () async {
    //           Navigator.of(context, rootNavigator: true).pop();
    //           await Navigator.push(
    //             context,
    //             MaterialPageRoute(
    //               builder: (context) => SecondScreen(payload),
    //             ),
    //           );
    //         },
    //       )
    //     ],
    //   ),
    // );
  }

  static Future _selectNotification(String? payload) async {
    print("selectNotification");
    // if (payload != null) {
    //   debugPrint('notification payload: $payload');
    // }
    // await Navigator.push(
    //   context,
    //   MaterialPageRoute<void>(builder: (context) => SecondScreen(payload)),
    // );
  }

  static Future<bool> isPamBackgroundMessageReceived(
      BuildContext context,
      Map<String, dynamic>? message) async {
    if (message == null) {
      return false;
    }
    if (message["pam"] == null) {
      return false;
    }

    Map<String, dynamic> rawPam = json.decode(message["pam"] ?? "{}");
    PamMessageModel pam = PamMessageModel.fromJson(await appPrefix(), rawPam);

    if (pam.PageTitle == "products") {
      await Navigator.of(context).pushAndRemoveUntil(
          MaterialPageRoute(builder: (context) => Scaffold(body: Pam.productPages()?.call() ?? Container(),)),
              (route) => false);
    } else if (pam.PageTitle == "product_detail") {
      await Navigator.of(Pam.context()).pushAndRemoveUntil(
          MaterialPageRoute(builder: (context) => Scaffold(body: Pam.productDetail()?.call(pam.Id ?? "") ?? Container(),)),
              (route) => false);
    }

    Pam.dispatch(PamStandardCallback.on_message, pam.toMap());
    return true;
  }

  static Future<bool> isPamForegroundMessageReceived(BuildContext context, Map<String, dynamic>? message) async {
    if (message == null) {
      return false;
    }
    if (message["pam"] == null) {
      return false;
    }

    Map<String, dynamic> rawPam = json.decode(message["pam"] ?? "{}");
    PamMessageModel pam = PamMessageModel.fromJson(await appPrefix(), rawPam);

    Pam.dispatch(PamStandardCallback.on_message, pam.toMap());
    return true;
  }
}

==> pam_flutter-1.1.34.tar.gz: lib/pam_notification.dart <==
import 'dart:convert';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_local_notifications/flutter_local_notifications.dart';
import 'package:pam_flutter/models/pam_message_model.dart';
import 'package:pam_flutter/pam_flutter.dart';
import 'package:pam_flutter/types.dart';
import 'package:flutter/services.dart' show rootBundle;

class PamNotification {
  PamNotification._();

  static String? _appPrefix;

  static Future<String> appPrefix() async {
    if (_appPrefix == null) {
      String raw = await rootBundle.loadString("pam-config.json");
      Map<String, dynamic> cfg = json.decode(raw);
      _appPrefix = cfg["app-prefix"];
    }
    return _appPrefix!;
  }

  static Future<void> pamInitial() async {
    FlutterLocalNotificationsPlugin flutterLocalNotificationsPlugin =
        FlutterLocalNotificationsPlugin();
    AndroidInitializationSettings initializationSettingsAndroid =
        AndroidInitializationSettings('app_icon');

    final IOSInitializationSettings initializationSettingsIOS =
        IOSInitializationSettings(
            onDidReceiveLocalNotification: _onDidReceiveLocalNotification);
    final InitializationSettings initializationSettings =
        InitializationSettings(
            android: initializationSettingsAndroid,
            iOS: initializationSettingsIOS);

    await flutterLocalNotificationsPlugin.initialize(initializationSettings,
        onSelectNotification: _selectNotification);
  }

  static Future _onDidReceiveLocalNotification(
      int id, String? title, String? body, String? payload) async {
    print("onDidReceiveLocalNotification");
    // showDialog(
    //   context: context,
    //   builder: (BuildContext context) => CupertinoAlertDialog(
    //     title: Text(title),
    //     content: Text(body),
    //     actions: [
    //       CupertinoDialogAction(
    //         isDefaultAction: true,
    //         child: Text('Ok'),
    //         onPressed: () async {
    //           Navigator.of(context, rootNavigator: true).pop();
    //           await Navigator.push(
    //             context,
    //             MaterialPageRoute(
    //               builder: (context) => SecondScreen(payload),
    //             ),
    //           );
    //         },
    //       )
    //     ],
    //   ),
    // );
  }

  static Future _selectNotification(String? payload) async {
    print("selectNotification");
    // if (payload != null) {
    //   debugPrint('notification payload: $payload');
    // }
    // await Navigator.push(
    //   context,
    //   MaterialPageRoute<void>(builder: (context) => SecondScreen(payload)),
    // );
  }

  static Future<bool> isPamBackgroundMessageReceived(
      BuildContext context, Map<String, dynamic>? message) async {
    if (message == null) {
      return false;
    }
    if (message["pam"] == null) {
      return false;
    }

    Map<String, dynamic> rawPam = json.decode(message["pam"] ?? "{}");
    PamMessageModel pam = PamMessageModel.fromJson(await appPrefix(), rawPam);

    if (pam.PageTitle == "product_detail") {
      await Navigator.of(Pam.context()).push(
        MaterialPageRoute(
          builder: (context) => Scaffold(
            body: Pam.productDetail()?.call(pam.Id ?? "") ?? Container(),
          ),
        ),
      );
    }

    Pam.dispatch(PamStandardCallback.on_message, pam.toMap());
    return true;
  }

  static Future<bool> isPamForegroundMessageReceived(
      BuildContext context, Map<String, dynamic>? message) async {
    if (message == null) {
      return false;
    }
    if (message["pam"] == null) {
      return false;
    }

    Map<String, dynamic> rawPam = json.decode(message["pam"] ?? "{}");
    PamMessageModel pam = PamMessageModel.fromJson(await appPrefix(), rawPam);

    Pam.dispatch(PamStandardCallback.on_message, pam.toMap());
    return true;
  }
}
